@@ -16,10 +16,8 @@
 import re
 import blockdiag.elements
 from utils.math import lcm
-from blockdiag import plugins
 from blockdiag.elements import *
 from blockdiag.utils import XY
-from rackdiag.plugins import NodeAttributes
 
 
 class RackItem(blockdiag.elements.DiagramNode):
@@ -125,13 +123,13 @@ class Rack(blockdiag.elements.NodeGroup):
     def _update_colwidth(self):
         widths = []
         for i in range(self.colheight):
-            nodes = [n for n in self.nodes  if n.xy.y == i]
+            nodes = [n for n in self.nodes if n.xy.y == i]
             if len(nodes) > 1:
                 widths.append(len(nodes))
 
         self.colwidth = lcm(*widths) or 1
         for i in range(self.colheight):
-            nodes = [n for n in self.nodes  if n.xy.y == i]
+            nodes = [n for n in self.nodes if n.xy.y == i]
             if nodes:
                 width = self.colwidth / len(nodes)
                 for i, node in enumerate(nodes):
@@ -171,14 +169,6 @@ class Diagram(blockdiag.elements.Diagram):
     def set_rackheight(self, value):
         self.racks[0].colheight = int(value)
 
-    def set_plugin(self, name, attrs):
-        if name == 'attributes':
-            kwargs = dict([a.name, a.value] for a in attrs)
-            handler = NodeAttributes(self, **kwargs)
-            plugins.install_node_handler(handler)
-        else:
-            super(Diagram, self).set_plugin(name, attrs)
-
     def fixiate(self):
         self.colwidth = sum(r.colwidth for r in self.racks)
         self.colheight = max(r.colheight for r in self.racks)
