@@ -16,10 +16,10 @@
 import os
 from docutils import nodes
 from docutils.parsers import rst
-from rackdiag import diagparser
+from rackdiag import parser
 from rackdiag.elements import RackItem
 from rackdiag.builder import ScreenNodeBuilder
-from rackdiag.DiagramDraw import DiagramDraw
+from rackdiag.drawer import DiagramDraw
 from blockdiag.utils.rst import directives
 
 
@@ -43,7 +43,7 @@ class RackdiagDirective(directives.BlockdiagDirective):
     node_class = rackdiag
 
     def node2diagram(self, node):
-        tree = diagparser.parse_string(node['code'])
+        tree = parser.parse_string(node['code'])
         return ScreenNodeBuilder.build(tree)
 
     def node2image(self, node, diagram):
@@ -87,9 +87,9 @@ class RackdiagDirective(directives.BlockdiagDirective):
 
         # records for total
         total = ['-', 'Total'] + [''] * (len(RackItem.desctable) - 2)
-        total[2] = u"%dU" % sum(n.colheight for n in nodes()  if n.colheight)
-        total[3] = u"%.1fA" % sum(n.ampere for n in nodes()  if n.ampere)
-        total[4] = u"%.1fkg" % sum(n.weight for n in nodes()  if n.weight)
+        total[2] = u"%dU" % sum(n.colheight for n in nodes() if n.colheight)
+        total[3] = u"%.1fA" % sum(n.ampere for n in nodes() if n.ampere)
+        total[4] = u"%.1fkg" % sum(n.weight for n in nodes() if n.weight)
         descriptions.append(total)
 
         for i in range(len(headers) - 1, -1, -1):
